@@ -31,8 +31,6 @@ impl<'a> Encoder<'a> {
             DynamicImage::ImageRgba8(image) => {
                 Ok(Self::from_rgba(image.as_ref(), image.width(), image.height()))
             }
-            DynamicImage::ImageBgr8(_) => { Err("Unimplemented") }
-            DynamicImage::ImageBgra8(_) => { Err("Unimplemented") }
             _ => { Err("Unimplemented") }
         }
     }
@@ -47,13 +45,13 @@ impl<'a> Encoder<'a> {
         Self { image, layout: PixelLayout::Rgba, width, height }
     }
 
-    /// Emcode the image with the given quality.
+    /// Encode the image with the given quality.
     /// The image quality must be between 0.0 and 100.0 inclusive for minimal and maximal quality respectively.
     pub fn encode(&self, quality: f32) -> WebPMemory {
         unsafe { encode(self.image, self.layout, self.width, self.height, quality) }
     }
 
-    /// Emcode the image losslessly.
+    /// Encode the image losslessly.
     pub fn encode_lossless(&self) -> WebPMemory {
         unsafe { encode(self.image, self.layout, self.width, self.height, -1.0) }
     }
